@@ -8,19 +8,22 @@
 package Image::IPTCInfo;
 
 use vars qw($VERSION);
-$VERSION = '1.9';
+$VERSION = '1.93';
 
 #
 # Global vars
 #
-use vars ('%datasets',		# master list of dataset id's
-		  '%datanames',     # reverse mapping (for saving)
-		  '%listdatasets',	# master list of repeating dataset id's
-		  '%listdatanames', # reverse
+use vars ('%datasets',		  # master list of dataset id's
+		  '%datanames',       # reverse mapping (for saving)
+		  '%listdatasets',	  # master list of repeating dataset id's
+		  '%listdatanames',   # reverse
+		  '$MAX_FILE_OFFSET', # maximum offset for blind scan
 		  );
 
+$MAX_FILE_OFFSET = 8192; # default blind scan depth
+
 # Debug off for production use
-my $debugMode = 0;
+my $debugMode = 1;
 my $error;
 	  
 #####################################
@@ -70,6 +73,7 @@ my $error;
 	116	=> 'copyright notice',
 #	118	=> 'contact',            # in listdatasets
 	120	=> 'caption/abstract',
+	121	=> 'local caption',
 	122	=> 'writer/editor',
 #	125	=> 'rasterized caption', # unsupported (binary data)
 	130	=> 'image type',
@@ -293,6 +297,21 @@ sub SetAttribute
 	$self->{_data}->{$attribute} = $newval;
 }
 
+sub ClearAttributes
+{
+	my $self = shift;
+
+	$self->{_data} = {};
+}
+
+sub ClearAllData
+{
+	my $self = shift;
+
+	$self->{_data} = {};
+	$self->{_listdata} = {};
+}
+
 #
 # Keywords/Clear/Add
 # 
@@ -767,16 +786,13 @@ sub JPEGSkipVariable
 #
 sub BlindScan
 {
-	my $MAX = shift;
-
-	$MAX = 8192 unless defined($MAX); # keep within first 8192 bytes 
-                                      # NOTE: this may need to change
-
-	Log("BlindScan: starting scan, max length $MAX");
+    my $maxoff = shift() || $MAX_FILE_OFFSET;
+    
+	Log("BlindScan: starting scan, max length $maxoff");
 	
 	# start digging
 	my $offset = 0;
-	while ($offset <= $MAX)
+	while ($offset <= $maxoff)
 	{
 		my $temp;
 		
@@ -1021,7 +1037,7 @@ sub CollectAdobeParts
 	my ($data) = @_;
 	my $length = length($data);
 	my $offset = 0;
-	my $out;
+	my $out = '';
 
 	# Skip preamble
 	$offset = length('Photoshop 3.0 ');
@@ -1031,21 +1047,29 @@ sub CollectAdobeParts
 	{
 		# Get OSType and ID
 		my ($ostype, $id1, $id2) = unpack("NCC", substr($data, $offset, 6));
-		$offset += 6;
+		last unless (($offset += 6) < $length); # $offset += 6;
 
+		# printf("CollectAdobeParts: ID %2.2x %2.2x\n", $id1, $id2);
+		
 		# Get pascal string
 		my ($stringlen) = unpack("C", substr($data, $offset, 1));
-		$offset += 1;
+		last unless (++$offset < $length); # $offset += 1;
+
+		# printf("CollectAdobeParts: str len %d\n", $stringlen);
+		
 		my $string = substr($data, $offset, $stringlen);
 		$offset += $stringlen;
 		# round up if odd
 		$offset++ if ($stringlen % 2 != 0);
 		# there should be a null if string len is 0
 		$offset++ if ($stringlen == 0);
+		last unless ($offset < $length);
 
 		# Get variable-size data
 		my ($size) = unpack("N", substr($data, $offset, 4));
-		$offset += 4;
+		last unless (($offset += 4) < $length);  # $offset += 4;
+
+		# printf("CollectAdobeParts: size %d\n", $size);
 
 		my $var = substr($data, $offset, $size);
 		$offset += $size;
@@ -1057,8 +1081,7 @@ sub CollectAdobeParts
 			$out .= pack("NCC", $ostype, $id1, $id2);
 			$out .= pack("C", $stringlen);
 			$out .= $string;
-			$out .= pack("C", 0) if ($stringlen == 0 || 
-									 $stringlen % 2 != 0);
+			$out .= pack("C", 0) if ($stringlen == 0 || $stringlen % 2 != 0);
 			$out .= pack("N", $size);
 			$out .= $var;
 			$out .= pack("C", 0) if ($size % 2 != 0 && length($out) % 2 != 0);
@@ -1113,6 +1136,8 @@ sub PackedIIMData
 		if ($dataset == 0)
 		{ Log("PackedIIMData: illegal dataname $key"); next; }
 
+        next unless $value;
+
 		my ($tag, $record) = (0x1c, 0x02);
 
 		$out .= pack("CCCn", $tag, $record, $dataset, length($value));
@@ -1129,6 +1154,8 @@ sub PackedIIMData
 
 		foreach my $value (@{$self->{_listdata}->{$key}})
 		{
+		    next unless $value;
+		    
 			my ($tag, $record) = (0x1c, 0x02);
 
 			$out .= pack("CCCn", $tag, $record, $dataset, length($value));
@@ -1439,28 +1466,28 @@ into the SQL.
 
 =head1 IPTC ATTRIBUTE REFERENCE
 
-  object name               originating program              
-  edit status               program version                  
-  editorial update          object cycle                     
-  urgency                   by-line                          
-  subject reference         by-line title                    
-  category                  city                             
-  fixture identifier        sub-location                     
-  content location code     province/state                   
-  content location name     country/primary location code    
-  release date              country/primary location name    
-  release time              original transmission reference  
-  expiration date           headline                         
-  expiration time           credit                           
-  special instructions      source                           
-  action advised            copyright notice                 
-  reference service         contact                          
-  reference date            caption/abstract                 
-  reference number          writer/editor                    
-  date created              image type                       
-  time created              image orientation                
-  digital creation date     language identifier
-  digital creation time
+  object name               originating program
+  edit status               program version
+  editorial update          object cycle
+  urgency                   by-line
+  subject reference         by-line title
+  category                  city
+  fixture identifier        sub-location
+  content location code     province/state
+  content location name     country/primary location code
+  release date              country/primary location name
+  release time              original transmission reference
+  expiration date           headline
+  expiration time           credit
+  special instructions      source
+  action advised            copyright notice
+  reference service         contact
+  reference date            caption/abstract
+  reference number          local caption
+  date created              writer/editor
+  time created              image type
+  digital creation date     image orientation
+  digital creation time     language identifier
 
   custom1 - custom20: NOT STANDARD but used by Fotostation.
   IPTCInfo also supports these fields.
